@@ -19,7 +19,6 @@ import (
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal/log"
 	"github.com/anchore/syft/syft/cpe"
-	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
 var (
@@ -37,10 +36,6 @@ type vulnerabilityProvider struct {
 	reader Reader
 }
 
-var _ interface {
-	vulnerability.Provider
-} = (*vulnerabilityProvider)(nil)
-
 // Deprecated: vulnerability.Vulnerability objects now have metadata included
 func (vp vulnerabilityProvider) VulnerabilityMetadata(ref vulnerability.Reference) (*vulnerability.Metadata, error) {
 	vuln, ok := ref.Internal.(*VulnerabilityHandle)
@@ -192,171 +187,37 @@ func (vp vulnerabilityProvider) Close() error {
 	return vp.reader.(io.Closer).Close()
 }
 
-//nolint:funlen,gocognit,gocyclo
 func (vp vulnerabilityProvider) FindVulnerabilities(criteria ...vulnerability.Criteria) ([]vulnerability.Vulnerability, error) {
 	if err := search.ValidateCriteria(criteria); err != nil {
 		return nil, err
 	}
 
-	var err error
-
 	var out []vulnerability.Vulnerability
 	for _, criteriaSet := range search.CriteriaIterator(criteria) {
-		var vulnSpecs VulnerabilitySpecifiers
-		var osSpecs OSSpecifiers
-		var pkgSpec *PackageSpecifier
-		var cpeSpec *cpe.Attributes
-		var pkgType syftPkg.Type
-
-		for i := 0; i < len(criteriaSet); i++ {
-			applied := false
-			switch c := criteriaSet[i].(type) {
-			case *search.PackageNameCriteria:
-				if pkgSpec == nil {
-					pkgSpec = &PackageSpecifier{}
-				}
-				pkgSpec.Name = c.PackageName
-				applied = true
-			case *search.EcosystemCriteria:
-				if pkgSpec == nil {
-					pkgSpec = &PackageSpecifier{}
-				}
-				// the v6 store normalizes ecosystems around the syft package type, so that field is preferred
-				switch {
-				case c.PackageType != "" && c.PackageType != syftPkg.UnknownPkg:
-					// prefer to match by a non-blank, known package type
-					pkgType = c.PackageType
-					pkgSpec.Ecosystem = string(c.PackageType)
-				case c.Language != "":
-					// if there's no known package type, but there is a non-blank language
-					// try that.
-					pkgSpec.Ecosystem = string(c.Language)
-				case c.PackageType == syftPkg.UnknownPkg:
-					// if language is blank, and package type is explicitly "UnknownPkg" and not
-					// just blank, use that.
-					pkgType = c.PackageType
-					pkgSpec.Ecosystem = string(c.PackageType)
-				}
-				applied = true
-			case *search.IDCriteria:
-				vulnSpecs = append(vulnSpecs, VulnerabilitySpecifier{
-					Name: c.ID,
-				})
-				applied = true
-			case *search.CPECriteria:
-				if cpeSpec == nil {
-					cpeSpec = &cpe.Attributes{}
-				}
-				*cpeSpec = c.CPE.Attributes
-				if cpeSpec.Product == cpe.Any {
-					return nil, fmt.Errorf("must specify product to search by CPE; got: %s", c.CPE.Attributes.BindToFmtString())
-				}
-				if pkgSpec == nil {
-					pkgSpec = &PackageSpecifier{}
-				}
-				pkgSpec.CPE = &c.CPE.Attributes
-				applied = true
-			case *search.DistroCriteria:
-				for _, d := range c.Distros {
-					var foundChannels int
-					for _, channel := range d.Channels {
-						if channel == "" {
-							// if the channel is empty, we should not add it to the OS specifier
-							continue
-						}
-						foundChannels++
-						osSpecs = append(osSpecs, &OSSpecifier{
-							Name:             d.Name(),
-							MajorVersion:     d.MajorVersion(),
-							MinorVersion:     d.MinorVersion(),
-							RemainingVersion: d.RemainingVersion(),
-							LabelVersion:     d.Codename,
-							Channel:          channel,
-						})
-					}
-					if foundChannels == 0 {
-						osSpecs = append(osSpecs, &OSSpecifier{
-							Name:             d.Name(),
-							MajorVersion:     d.MajorVersion(),
-							MinorVersion:     d.MinorVersion(),
-							RemainingVersion: d.RemainingVersion(),
-							LabelVersion:     d.Codename,
-						})
-					}
-				}
-				applied = true
-			}
-
-			// remove fully applied criteria from later checks
-			if applied {
-				criteriaSet = append(criteriaSet[0:i], criteriaSet[i+1:]...)
-				i--
-			}
-		}
-
-		if len(osSpecs) == 0 {
-			// we don't want to search across all distros, instead if the user did not specify a distro we should assume that
-			// they want to search across affected packages not associated with any distro.
-			osSpecs = append(osSpecs, NoOSSpecified)
-		}
-
-		// if there is an ecosystem provided and a name, we need to make certain that we're using the name normalization
-		// rules specific to the ecosystem before searching.
-		if pkgType != "" && pkgSpec.Name != "" {
-			pkgSpec.Name = name.Normalize(pkgSpec.Name, pkgType)
-		}
-
-		versionMatcher, remainingCriteria := splitConstraintMatcher(criteriaSet...)
-
-		var affectedPackages []AffectedPackageHandle
-		var affectedCPEs []AffectedCPEHandle
-
-		if pkgSpec != nil || len(vulnSpecs) > 0 {
-			affectedPackages, err = vp.reader.GetAffectedPackages(pkgSpec, &GetAffectedPackageOptions{
-				OSs:             osSpecs,
-				Vulnerabilities: vulnSpecs,
-				PreloadBlob:     true,
-			})
-			if err != nil {
-				if errors.Is(err, ErrOSNotPresent) {
-					log.WithFields("os", osSpecs).Debug("no OS found in the DB for the given criteria")
-					return nil, nil
-				}
-				return nil, err
-			}
-
-			affectedPackages = filterAffectedPackageVersions(versionMatcher, affectedPackages)
-
-			// after filtering, read vulnerability data
-			if err = fillAffectedPackageHandles(vp.reader, ptrs(affectedPackages)); err != nil {
-				return nil, err
-			}
-		}
-
-		if cpeSpec != nil {
-			affectedCPEs, err = vp.reader.GetAffectedCPEs(cpeSpec, &GetAffectedCPEOptions{
-				Vulnerabilities: vulnSpecs,
-				PreloadBlob:     true,
-			})
-			if err != nil {
-				return nil, err
-			}
-
-			affectedCPEs = filterAffectedCPEVersions(versionMatcher, affectedCPEs, cpeSpec)
-
-			// after filtering, read vulnerability data
-			if err = fillAffectedCPEHandles(vp.reader, ptrs(affectedCPEs)); err != nil {
-				return nil, err
-			}
-		}
-
-		// fill complete vulnerabilities for this set -- these should have already had all properties lazy loaded
-		vulns, err := vp.toVulnerabilities(affectedPackages, affectedCPEs)
+		// parse criteria into a search query object
+		query, remainingCriteria, err := newSearchQuery(criteriaSet)
 		if err != nil {
 			return nil, err
 		}
 
-		// filter vulnerabilities by any remaining criteria such as ByQualifiedPackages
+		// fetch and process packages
+		pkgVulns, err := vp.fetchAndProcessPackages(query)
+		if err != nil {
+			return nil, err
+		}
+
+		// fetch and process CPEs
+		cpeVulns, err := vp.fetchAndProcessCPEs(query)
+		if err != nil {
+			return nil, err
+		}
+
+		// combine vulnerabilities
+		var vulns []vulnerability.Vulnerability
+		vulns = append(vulns, pkgVulns...)
+		vulns = append(vulns, cpeVulns...)
+
+		// apply remaining filters
 		vulns, err = vp.filterVulnerabilities(vulns, remainingCriteria...)
 		if err != nil {
 			return nil, err
@@ -368,6 +229,148 @@ func (vp vulnerabilityProvider) FindVulnerabilities(criteria ...vulnerability.Cr
 	return out, nil
 }
 
+// fetchAndProcessPackages fetches packages and returns vulnerabilities directly
+func (vp vulnerabilityProvider) fetchAndProcessPackages(query *searchQuery) ([]vulnerability.Vulnerability, error) {
+	// only fetch if we have package specifications or vulnerability specifications
+	if query.pkgSpec == nil && len(query.vulnSpecs) == 0 {
+		return nil, nil
+	}
+
+	if query.unaffectedOnly {
+		return vp.fetchAndProcessUnaffectedPackages(query)
+	}
+	return vp.fetchAndProcessAffectedPackages(query)
+}
+
+// fetchAndProcessAffectedPackages fetches affected packages and returns vulnerabilities
+func (vp vulnerabilityProvider) fetchAndProcessAffectedPackages(query *searchQuery) ([]vulnerability.Vulnerability, error) {
+	var vulns []vulnerability.Vulnerability
+	metadataCache := make(map[string]*vulnerability.Metadata)
+
+	affectedPackages, err := vp.reader.GetAffectedPackages(query.pkgSpec, &GetPackageOptions{
+		OSs:             query.osSpecs,
+		Vulnerabilities: query.vulnSpecs,
+		PreloadBlob:     true,
+	})
+	if err != nil {
+		if err = vp.handleOSError(err, query.osSpecs); err != nil {
+			return nil, err
+		}
+		// if handleOSError returned nil, it means ErrOSNotPresent was handled
+		return vulns, nil
+	}
+
+	affectedPackages = filterAffectedPackageVersions(query.versionMatcher, affectedPackages)
+
+	if err = fillAffectedPackageHandles(vp.reader, ptrs(affectedPackages)); err != nil {
+		return nil, err
+	}
+
+	vulns, err = vp.processAffectedPackageHandles(vulns, affectedPackages, metadataCache)
+	if err != nil {
+		return nil, err
+	}
+
+	return vulns, nil
+}
+
+// fetchAndProcessUnaffectedPackages fetches unaffected packages and returns vulnerabilities
+func (vp vulnerabilityProvider) fetchAndProcessUnaffectedPackages(query *searchQuery) ([]vulnerability.Vulnerability, error) {
+	var vulns []vulnerability.Vulnerability
+	metadataCache := make(map[string]*vulnerability.Metadata)
+
+	unaffectedPackages, err := vp.reader.GetUnaffectedPackages(query.pkgSpec, &GetPackageOptions{
+		OSs:             query.osSpecs,
+		Vulnerabilities: query.vulnSpecs,
+		PreloadBlob:     true,
+	})
+	if err != nil {
+		if err = vp.handleOSError(err, query.osSpecs); err != nil {
+			return nil, err
+		}
+		// if handleOSError returned nil, it means ErrOSNotPresent was handled
+		return vulns, nil
+	}
+
+	unaffectedPackages = filterUnaffectedPackageVersions(query.versionMatcher, unaffectedPackages)
+
+	if err = fillUnaffectedPackageHandles(vp.reader, ptrs(unaffectedPackages)); err != nil {
+		return nil, err
+	}
+
+	vulns, err = vp.processUnaffectedPackageHandles(vulns, unaffectedPackages, metadataCache)
+	if err != nil {
+		return nil, err
+	}
+
+	return vulns, nil
+}
+
+// handleOSError handles the common pattern of checking for ErrOSNotPresent
+func (vp vulnerabilityProvider) handleOSError(err error, osSpecs OSSpecifiers) error {
+	if err == nil {
+		return nil
+	}
+	if errors.Is(err, ErrOSNotPresent) {
+		log.WithFields("os", osSpecs).Debug("no OS found in the DB for the given criteria")
+		return nil
+	}
+	return err
+}
+
+// fetchAndProcessCPEs fetches CPEs and returns vulnerabilities directly
+func (vp vulnerabilityProvider) fetchAndProcessCPEs(query *searchQuery) ([]vulnerability.Vulnerability, error) {
+	var vulns []vulnerability.Vulnerability
+	metadataCache := make(map[string]*vulnerability.Metadata)
+
+	// only fetch if we have CPE specifications
+	if query.cpeSpec == nil {
+		return vulns, nil
+	}
+
+	if query.unaffectedOnly {
+		unaffectedCPEs, err := vp.reader.GetUnaffectedCPEs(query.cpeSpec, &GetCPEOptions{
+			Vulnerabilities: query.vulnSpecs,
+			PreloadBlob:     true,
+		})
+		if err != nil {
+			return nil, err
+		}
+
+		unaffectedCPEs = filterUnaffectedCPEVersions(query.versionMatcher, unaffectedCPEs, query.cpeSpec)
+
+		if err = fillUnaffectedCPEHandles(vp.reader, ptrs(unaffectedCPEs)); err != nil {
+			return nil, err
+		}
+
+		vulns, err = vp.processUnaffectedCPEHandles(vulns, unaffectedCPEs, metadataCache)
+		if err != nil {
+			return nil, err
+		}
+	} else {
+		affectedCPEs, err := vp.reader.GetAffectedCPEs(query.cpeSpec, &GetCPEOptions{
+			Vulnerabilities: query.vulnSpecs,
+			PreloadBlob:     true,
+		})
+		if err != nil {
+			return nil, err
+		}
+
+		affectedCPEs = filterAffectedCPEVersions(query.versionMatcher, affectedCPEs, query.cpeSpec)
+
+		if err = fillAffectedCPEHandles(vp.reader, ptrs(affectedCPEs)); err != nil {
+			return nil, err
+		}
+
+		vulns, err = vp.processAffectedCPEHandles(vulns, affectedCPEs, metadataCache)
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	return vulns, nil
+}
+
 func (vp vulnerabilityProvider) filterVulnerabilities(vulns []vulnerability.Vulnerability, criteria ...vulnerability.Criteria) ([]vulnerability.Vulnerability, error) {
 	isMatch := func(v vulnerability.Vulnerability) (bool, error) {
 		for _, c := range criteria {
@@ -402,36 +405,14 @@ func (vp vulnerabilityProvider) filterVulnerabilities(vulns []vulnerability.Vuln
 	return vulns, nil
 }
 
-// toVulnerabilities takes fully-filled handles and returns all vulnerabilities from them
-func (vp vulnerabilityProvider) toVulnerabilities(packageHandles []AffectedPackageHandle, cpeHandles []AffectedCPEHandle) ([]vulnerability.Vulnerability, error) { //nolint:funlen,gocognit
-	var out []vulnerability.Vulnerability
-
-	metadataByCVE := make(map[string]*vulnerability.Metadata)
-
-	getMetadata := func(vuln *VulnerabilityHandle, namespace string) (*vulnerability.Metadata, error) {
-		if vuln == nil {
-			return nil, nil
-		}
-
-		if metadata, ok := metadataByCVE[vuln.Name]; ok {
-			return metadata, nil
-		}
-
-		metadata, err := vp.getVulnerabilityMetadata(vuln, namespace)
-		if err != nil {
-			return nil, err
-		}
-
-		metadataByCVE[vuln.Name] = metadata
-		return metadata, nil
-	}
-
-	for _, packageHandle := range packageHandles {
-		if packageHandle.BlobValue == nil {
-			log.Debugf("unable to find blobValue for %+v", packageHandle)
+// processAffectedPackageHandles processes affected package handles and adds them to the vulnerabilities list
+func (vp vulnerabilityProvider) processAffectedPackageHandles(out []vulnerability.Vulnerability, handles []AffectedPackageHandle, metadataCache map[string]*vulnerability.Metadata) ([]vulnerability.Vulnerability, error) {
+	for _, ph := range handles {
+		if ph.BlobValue == nil {
+			log.Debugf("unable to find blobValue for %+v", ph)
 			continue
 		}
-		v, err := newVulnerabilityFromAffectedPackageHandle(packageHandle, packageHandle.BlobValue.Ranges)
+		v, err := newVulnerabilityFromAffectedPackageHandle(ph, ph.BlobValue.Ranges)
 		if err != nil {
 			return nil, err
 		}
@@ -439,7 +420,7 @@ func (vp vulnerabilityProvider) toVulnerabilities(packageHandles []AffectedPacka
 			continue
 		}
 
-		meta, err := getMetadata(packageHandle.Vulnerability, v.Namespace)
+		meta, err := vp.getCachedMetadata(ph.Vulnerability, v.Namespace, metadataCache)
 		if err != nil {
 			log.WithFields("error", err, "vulnerability", v.String()).Debug("unable to fetch metadata for vulnerability")
 		} else {
@@ -448,49 +429,107 @@ func (vp vulnerabilityProvider) toVulnerabilities(packageHandles []AffectedPacka
 
 		out = append(out, *v)
 	}
-
-	for _, c := range cpeHandles {
-		if c.BlobValue == nil {
-			log.Debugf("unable to find blobValue for %+v", c)
-			continue
-		}
-		v, err := newVulnerabilityFromAffectedCPEHandle(c, c.BlobValue.Ranges)
-		if err != nil {
-			return nil, err
-		}
-		if v == nil {
-			continue
-		}
-
-		meta, err := getMetadata(c.Vulnerability, v.Namespace)
-		if err != nil {
-			log.WithFields("error", err, "vulnerability", v.String()).Debug("unable to fetch metadata for vulnerability")
-		} else {
-			v.Metadata = meta
-		}
-
-		out = append(out, *v)
-	}
-
 	return out, nil
 }
 
-// splitConstraintMatcher returns a search.VersionConstraintMatcher from all search.VersionConstraintMatcher(s) in the criteria
-func splitConstraintMatcher(criteria ...vulnerability.Criteria) (search.VersionConstraintMatcher, []vulnerability.Criteria) {
-	var remaining []vulnerability.Criteria
-	var matcher search.VersionConstraintMatcher
-	for _, c := range criteria {
-		if nextMatcher, ok := c.(search.VersionConstraintMatcher); ok {
-			if matcher == nil {
-				matcher = nextMatcher
-			} else {
-				matcher = search.MultiConstraintMatcher(matcher, nextMatcher)
-			}
-		} else {
-			remaining = append(remaining, c)
+// processAffectedCPEHandles processes affected CPE handles and adds them to the vulnerabilities list
+func (vp vulnerabilityProvider) processAffectedCPEHandles(out []vulnerability.Vulnerability, handles []AffectedCPEHandle, metadataCache map[string]*vulnerability.Metadata) ([]vulnerability.Vulnerability, error) {
+	for _, ch := range handles {
+		if ch.BlobValue == nil {
+			log.Debugf("unable to find blobValue for %+v", ch)
+			continue
 		}
+		v, err := newVulnerabilityFromAffectedCPEHandle(ch, ch.BlobValue.Ranges)
+		if err != nil {
+			return nil, err
+		}
+		if v == nil {
+			continue
+		}
+
+		meta, err := vp.getCachedMetadata(ch.Vulnerability, v.Namespace, metadataCache)
+		if err != nil {
+			log.WithFields("error", err, "vulnerability", v.String()).Debug("unable to fetch metadata for vulnerability")
+		} else {
+			v.Metadata = meta
+		}
+
+		out = append(out, *v)
 	}
-	return matcher, remaining
+	return out, nil
+}
+
+// processUnaffectedPackageHandles processes unaffected package handles and adds them to the vulnerabilities list
+func (vp vulnerabilityProvider) processUnaffectedPackageHandles(out []vulnerability.Vulnerability, handles []UnaffectedPackageHandle, metadataCache map[string]*vulnerability.Metadata) ([]vulnerability.Vulnerability, error) {
+	for _, ph := range handles {
+		if ph.BlobValue == nil {
+			log.Debugf("unable to find blobValue for %+v", ph)
+			continue
+		}
+		v, err := newVulnerabilityFromUnaffectedPackageHandle(ph, ph.BlobValue.Ranges)
+		if err != nil {
+			return nil, err
+		}
+		if v == nil {
+			continue
+		}
+
+		meta, err := vp.getCachedMetadata(ph.Vulnerability, v.Namespace, metadataCache)
+		if err != nil {
+			log.WithFields("error", err, "vulnerability", v.String()).Debug("unable to fetch metadata for vulnerability")
+		} else {
+			v.Metadata = meta
+		}
+
+		out = append(out, *v)
+	}
+	return out, nil
+}
+
+// processUnaffectedCPEHandles processes unaffected CPE handles and adds them to the vulnerabilities list
+func (vp vulnerabilityProvider) processUnaffectedCPEHandles(out []vulnerability.Vulnerability, handles []UnaffectedCPEHandle, metadataCache map[string]*vulnerability.Metadata) ([]vulnerability.Vulnerability, error) {
+	for _, ch := range handles {
+		if ch.BlobValue == nil {
+			log.Debugf("unable to find blobValue for %+v", ch)
+			continue
+		}
+		v, err := newVulnerabilityFromUnaffectedCPEHandle(ch, ch.BlobValue.Ranges)
+		if err != nil {
+			return nil, err
+		}
+		if v == nil {
+			continue
+		}
+
+		meta, err := vp.getCachedMetadata(ch.Vulnerability, v.Namespace, metadataCache)
+		if err != nil {
+			log.WithFields("error", err, "vulnerability", v.String()).Debug("unable to fetch metadata for vulnerability")
+		} else {
+			v.Metadata = meta
+		}
+
+		out = append(out, *v)
+	}
+	return out, nil
+}
+
+// getCachedMetadata retrieves metadata from cache or fetches it if not cached
+func (vp vulnerabilityProvider) getCachedMetadata(vuln *VulnerabilityHandle, namespace string, metadataCache map[string]*vulnerability.Metadata) (*vulnerability.Metadata, error) {
+	if vuln == nil {
+		return nil, nil
+	}
+
+	if metadata, ok := metadataCache[vuln.Name]; ok {
+		return metadata, nil
+	}
+
+	metadata, err := vp.getVulnerabilityMetadata(vuln, namespace)
+	if err != nil {
+		return nil, err
+	}
+
+	metadataCache[vuln.Name] = metadata
+	return metadata, nil
 }
 
 func filterAffectedPackageVersions(constraintMatcher search.VersionConstraintMatcher, packages []AffectedPackageHandle) []AffectedPackageHandle {
@@ -521,6 +560,35 @@ func filterAffectedPackageVersions(constraintMatcher search.VersionConstraintMat
 	return out
 }
 
+func filterUnaffectedPackageVersions(constraintMatcher search.VersionConstraintMatcher, packages []UnaffectedPackageHandle) []UnaffectedPackageHandle {
+	// no constraint matcher, just return all packages
+	if constraintMatcher == nil {
+		return packages
+	}
+	var out []UnaffectedPackageHandle
+	for packageIdx := 0; packageIdx < len(packages); packageIdx++ {
+		handle := packages[packageIdx]
+		vuln := handle.vulnerability()
+		pkgHandle := handle.getPackageHandle()
+		allDropped, unmatchedConstraints := filterAffectedPackageRanges(constraintMatcher, pkgHandle.BlobValue)
+		if !allDropped {
+			out = append(out, handle)
+			continue // keep this handle
+		}
+
+		reason := fmt.Sprintf("not within vulnerability version constraints: %q", strings.Join(unmatchedConstraints, ", "))
+		f := make(logger.Fields)
+		if pkgHandle.Package != nil {
+			f["package"] = pkgHandle.Package.String()
+		} else {
+			f["unaffectedPackage"] = handle
+		}
+
+		logDroppedVulnerability(vuln, reason, f)
+	}
+	return out
+}
+
 func filterAffectedCPEVersions(constraintMatcher search.VersionConstraintMatcher, handles []AffectedCPEHandle, cpeSpec *cpe.Attributes) []AffectedCPEHandle {
 	// no constraint matcher, just return all packages
 	if constraintMatcher == nil {
@@ -544,8 +612,31 @@ func filterAffectedCPEVersions(constraintMatcher search.VersionConstraintMatcher
 	return out
 }
 
+func filterUnaffectedCPEVersions(constraintMatcher search.VersionConstraintMatcher, handles []UnaffectedCPEHandle, cpeSpec *cpe.Attributes) []UnaffectedCPEHandle {
+	// no constraint matcher, just return all packages
+	if constraintMatcher == nil {
+		return handles
+	}
+	var out []UnaffectedCPEHandle
+	for i := range handles {
+		handle := handles[i]
+		vuln := handle.vulnerability()
+		allDropped, unmatchedConstraints := filterAffectedPackageRanges(constraintMatcher, handle.BlobValue)
+		if !allDropped {
+			out = append(out, handle)
+			continue // keep this handle
+		}
+
+		reason := fmt.Sprintf("not within vulnerability version constraints: %q", strings.Join(unmatchedConstraints, ", "))
+		logDroppedVulnerability(vuln, reason, logger.Fields{
+			"cpe": cpeSpec.String(),
+		})
+	}
+	return out
+}
+
 // filterAffectedPackageRanges returns true if all ranges removed
-func filterAffectedPackageRanges(matcher search.VersionConstraintMatcher, b *AffectedPackageBlob) (bool, []string) {
+func filterAffectedPackageRanges(matcher search.VersionConstraintMatcher, b *PackageBlob) (bool, []string) {
 	if len(b.Ranges) == 0 {
 		// no ranges means that we're implicitly vulnerable to all versions
 		return false, nil
