@@ -536,34 +536,66 @@ func Test_getRelatedVulnerabilities(t *testing.T) {
 	tests := []struct {
 		name     string
 		vuln     VulnerabilityHandle
-		affected AffectedPackageBlob
-		expected []string
+		affected PackageBlob
+		language string
+		expected []vulnerability.Reference
 	}{
 		{
 			name: "GHSA with related CVEs",
 			vuln: VulnerabilityHandle{
-				Name: "GHSA-1234",
+				Name:       "GHSA-1234",
+				ProviderID: githubProvider,
 				BlobValue: &VulnerabilityBlob{
 					Aliases: []string{"CVE-2024-1"},
 				},
 			},
-			affected: AffectedPackageBlob{
+			affected: PackageBlob{
 				CVEs: []string{"CVE-2024-2", "CVE-2024-3"},
 			},
-			expected: []string{"CVE-2024-1", "CVE-2024-2", "CVE-2024-3"},
+			language: "python",
+			expected: []vulnerability.Reference{
+				{ID: "CVE-2024-1", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-2", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-3", Namespace: v5NvdNamespace},
+			},
+		},
+		{
+			name: "CGA with related GHSA",
+			vuln: VulnerabilityHandle{
+				Name:       "CGA-1234",
+				ProviderID: githubProvider,
+				BlobValue: &VulnerabilityBlob{
+					Aliases: []string{"GHSA-1234"},
+				},
+			},
+			affected: PackageBlob{
+				CVEs: []string{"CVE-2024-2", "CVE-2024-3"},
+			},
+			language: "python",
+			expected: []vulnerability.Reference{
+				{ID: "GHSA-1234", Namespace: "github:language:python"},
+				{ID: "CVE-2024-2", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-3", Namespace: v5NvdNamespace},
+			},
 		},
 		{
 			name: "CVE with related CVEs",
 			vuln: VulnerabilityHandle{
-				Name: "CVE-2024-1234",
+				Name:       "CVE-2024-1234",
+				ProviderID: "rhel",
 				BlobValue: &VulnerabilityBlob{
 					Aliases: []string{"CVE-2024-1"},
 				},
 			},
-			affected: AffectedPackageBlob{
+			affected: PackageBlob{
 				CVEs: []string{"CVE-2024-2", "CVE-2024-3"},
 			},
-			expected: []string{"CVE-2024-1234", "CVE-2024-1", "CVE-2024-2", "CVE-2024-3"},
+			expected: []vulnerability.Reference{
+				{ID: "CVE-2024-1234", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-1", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-2", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-3", Namespace: v5NvdNamespace},
+			},
 		},
 		{
 			name: "nvd CVE skips related CVEs to self",
@@ -574,50 +606,53 @@ func Test_getRelatedVulnerabilities(t *testing.T) {
 					Aliases: []string{"CVE-2024-1", "CVE-2024-1234"},
 				},
 			},
-			affected: AffectedPackageBlob{
+			affected: PackageBlob{
 				CVEs: []string{"CVE-2024-2", "CVE-2024-1234"},
 			},
-			expected: []string{"CVE-2024-1", "CVE-2024-2"}, // does not include "CVE-2024-1234"
+			expected: []vulnerability.Reference{
+				{ID: "CVE-2024-1", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-2", Namespace: v5NvdNamespace},
+			}, // does not include "CVE-2024-1234"
 		},
 		{
 			name: "non-nvd CVE with related nvd CVEs to self",
 			vuln: VulnerabilityHandle{
-				Name: "CVE-2024-1234",
+				Name:       "CVE-2024-1234",
+				ProviderID: "rhel",
 				BlobValue: &VulnerabilityBlob{
 					Aliases: []string{"CVE-2024-1", "CVE-2024-1234"},
 				},
 			},
-			affected: AffectedPackageBlob{
+			affected: PackageBlob{
 				CVEs: []string{"CVE-2024-2", "CVE-2024-1234"},
 			},
-			expected: []string{"CVE-2024-1", "CVE-2024-2", "CVE-2024-1234"}, // does include "CVE-2024-1234"
+			expected: []vulnerability.Reference{
+				{ID: "CVE-2024-1", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-2", Namespace: v5NvdNamespace},
+				{ID: "CVE-2024-1234", Namespace: v5NvdNamespace},
+			}, // does include "CVE-2024-1234"
 		},
 		{
 			name: "non-nvd CVE always relates back to NVD",
 			vuln: VulnerabilityHandle{
 				Name:       "CVE-2024-1234",
-				ProviderID: "1234",
+				ProviderID: "rhel",
 				BlobValue: &VulnerabilityBlob{
 					Aliases: []string{},
 				},
 			},
-			affected: AffectedPackageBlob{
+			affected: PackageBlob{
 				CVEs: []string{},
 			},
-			expected: []string{"CVE-2024-1234"}, // does include "CVE-2024-1234"
+			expected: []vulnerability.Reference{
+				{ID: "CVE-2024-1234", Namespace: v5NvdNamespace},
+			}, // does include "CVE-2024-1234"
 		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			got := getRelatedVulnerabilities(&tt.vuln, &tt.affected)
-			var expected []vulnerability.Reference
-			for _, name := range tt.expected {
-				expected = append(expected, vulnerability.Reference{
-					ID:        name,
-					Namespace: v5NvdNamespace,
-				})
-			}
-			require.ElementsMatch(t, expected, got)
+			got := getRelatedVulnerabilities(&tt.vuln, &tt.affected, tt.language)
+			require.ElementsMatch(t, tt.expected, got)
 		})
 	}
 }
@@ -628,17 +663,17 @@ func TestToFix(t *testing.T) {
 
 	tests := []struct {
 		name           string
-		affectedRanges []AffectedRange
+		affectedRanges []Range
 		expectedFix    vulnerability.Fix
 	}{
 		{
 			name:           "empty affected ranges",
-			affectedRanges: []AffectedRange{},
+			affectedRanges: []Range{},
 			expectedFix:    vulnerability.Fix{},
 		},
 		{
 			name: "all ranges have nil fix",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{Fix: nil},
 				{Fix: nil},
 			},
@@ -646,7 +681,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "single fixed version without available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -662,7 +697,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "single fixed version with complete available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -690,7 +725,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "fix detail is nil - no available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -707,7 +742,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "fix detail available is nil - no available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -726,7 +761,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "fix detail available date is nil - no available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -748,7 +783,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "multiple fixed versions with mixed available info",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -805,7 +840,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "wont fix status only",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -821,7 +856,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "not fixed status only",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -837,7 +872,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "not affected status - not handled yet",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -849,7 +884,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "fixed status overrides wont fix",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -871,7 +906,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "fixed status overrides not fixed",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -893,7 +928,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "wont fix overrides not fixed",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
@@ -915,7 +950,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "mix of nil fixes and various states",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{Fix: nil},
 				{
 					Fix: &Fix{
@@ -951,7 +986,7 @@ func TestToFix(t *testing.T) {
 		},
 		{
 			name: "available with empty kind field",
-			affectedRanges: []AffectedRange{
+			affectedRanges: []Range{
 				{
 					Fix: &Fix{
 						Version: "1.2.3",
